{
  pkgs,
  inputs,
  ...
}:
{
  imports = [
    ./hardware-configuration.nix
    inputs.disko.nixosModules.disko
    inputs.nixos-hardware.nixosModules.common-cpu-intel
    ./disko.nix
  ];

  hardware.graphics = {
    enable = true;
    enable32Bit = true;
  };

  zramSwap.enable = true;
  boot.kernelPackages = pkgs.linuxPackages_6_11;
  networking.hostName = "lenar";

  services.power-profiles-daemon.enable = false;
  services.tlp = {
    enable = true;
    settings = {
      DEVICES_TO_DISABLE_ON_STARTUP = "bluetooth";
    };
  };

  # My own modules configuration
  krop = {
    audio = {
      enable = true;
    };
    ide = {
      enable = true;
      install-pycharm = true;
      install-goland = true;
      install-webstorm = true;
      install-datagrip = true;
      install-clion = true;
    };
    python = {
      enable = true;
      install-additional = true;
    };
    cli = {
      enable = true;
      install-k8s-tools = true;
      install-cloud-cli = true;
    };
    docker = {
      enable = true;
      changeDefaultNetwork = true;
    };
    waydroid.enable = true;
    podman.enable = true;
    de.gnome = {
      enable = true;
    };
  };

  systemd.services.configure-mic-leds = rec {
    wantedBy = [ "sound.target" ];
    after = wantedBy;
    serviceConfig.Type = "oneshot";
    script = ''
      echo off > /sys/class/sound/ctl-led/mic/mode
    '';
  };

  home-manager = {
    users = {
      "krop" = import ./home.nix;
    };
  };
}
