{
  pkgs,
  inputs,
  config,
  ...
}:
{
  imports = [
    ./hardware-configuration.nix
    inputs.disko.nixosModules.disko
    inputs.nixos-hardware.nixosModules.common-cpu-intel
    ./disko.nix
  ];

  boot.loader.systemd-boot = {
    windows = {
      "10" = {
        title = "Windows 10";
        efiDeviceHandle = "HD2b";
      };
    };
  };

  zramSwap.enable = true;
  boot.kernelPackages = pkgs.linuxPackages_6_11;
  networking.hostName = "wenar-nix";

  hardware.graphics.enable = true;

  services.xserver.videoDrivers = [ "nvidia" ];

  hardware.nvidia = {
    modesetting.enable = true;
    powerManagement.enable = false;
    powerManagement.finegrained = false;
    open = true;
    package = config.boot.kernelPackages.nvidiaPackages.latest;
  };

  hardware.xone.enable = true;

  # My own modules configuration
  krop = {
    audio = {
      enable = true;
    };
    ide = {
      enable = true;
      install-pycharm = true;
      install-goland = true;
    };
    python = {
      enable = true;
      install-additional = true;
    };
    cli = {
      enable = true;
      install-k8s-tools = true;
      install-cloud-cli = true;
    };
    docker = {
      enable = true;
      changeDefaultNetwork = true;
    };
    de.plasma = {
      enable = true;
    };
  };

  home-manager = {
    users = {
      "krop" = import ./home.nix;
    };
  };
}
